<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns="urn:oasis:names:tc:xliff:document:1.2"
	xmlns:s="http://www.w3.org/2000/svg"
	xmlns:v="http://ns.adobe.com/Variables/1.0/"
	xmlns:c="http://ns.adobe.com/GenericCustomNamespace/1.0/"
	exclude-result-prefixes="s v c">

	<xsl:output indent="yes"/>

	<!-- Stylesheet to produce merged xliff -->

	<xsl:param name="original"/>
	<xsl:param name="datatype" select="'html'"/>
	<xsl:param name="sourceLanguage"/>
	<xsl:param name="allTargetLanguages" select="false()"/>
	<xsl:param name="targetLanguageSelection" select="false()"/>

	<xsl:variable name="sourceLangCode">
		<xsl:choose>
			<xsl:when test="contains($sourceLanguage, '·')">
				<xsl:value-of select="normalize-space(substring-before($sourceLanguage, '·'))"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="normalize-space($sourceLanguage)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="sourceLangDataSet">
		<xsl:choose>
			<xsl:when test="contains($sourceLanguage, '·')">
				<xsl:value-of select="normalize-space(substring-after($sourceLanguage, '·'))"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="normalize-space($sourceLanguage)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="allTargetLangString">
		<xsl:if test="$allTargetLanguages">
			<xsl:for-each select="/svg/v:variableSets/v:variableSet/v:sampleDataSets/v:sampleDataSet[@dataSetName != $sourceLangDataSet]
					| /s:svg/v:variableSets/v:variableSet/v:sampleDataSets/v:sampleDataSet[@dataSetName != $sourceLangDataSet]">
				<xsl:value-of select="concat('|', @dataSetName)"/>
			</xsl:for-each>
		</xsl:if>
	</xsl:variable>
	<xsl:variable name="targetLangs">
		<xsl:choose>
			<xsl:when test="$allTargetLanguages">
				<xsl:value-of select="substring($allTargetLangString, 2)"/>
			</xsl:when>
			<xsl:when test="$targetLanguageSelection">
				<xsl:value-of select="normalize-space($targetLanguageSelection)"/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>

	<xsl:template match="/">
		<xliff version="1.2">
			<xsl:call-template name="sourceFile"/>
			<xsl:if test="$targetLangs">
				<xsl:call-template name="targetFiles"/>
			</xsl:if>
		</xliff>
	</xsl:template>

	<xsl:template name="sourceFile">
		<file original="{$original}" source-language="{$sourceLangCode}" datatype="{$datatype}">
			<body>
				<xsl:apply-templates select="/svg | /s:svg">
					<xsl:with-param name="dataSet" select="false()"/>
				</xsl:apply-templates>
			</body>
		</file>
	</xsl:template>

	<xsl:template name="targetFiles">
		<xsl:param name="langs" select="$targetLangs"/>
		<xsl:variable name="activeLang">
			<xsl:choose>
				<xsl:when test="contains($langs, '|')">
					<xsl:value-of select="normalize-space(substring-before($langs,'|'))"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space($langs)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="targetLangCode">
			<xsl:choose>
				<xsl:when test="contains($activeLang, '·')">
					<xsl:value-of select="normalize-space(substring-before($activeLang, '·'))"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space($activeLang)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="targetLangDataSet">
			<xsl:choose>
				<xsl:when test="contains($activeLang, '·')">
					<xsl:value-of select="normalize-space(substring-after($activeLang, '·'))"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space($activeLang)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<file original="{$original}" source-language="{$sourceLangCode}" target-language="{$targetLangCode}" datatype="{$datatype}">
			<body>
				<xsl:apply-templates select="/svg | /s:svg">
					<xsl:with-param name="dataSet" select="$targetLangDataSet"/>
				</xsl:apply-templates>
			</body>
		</file>
		<xsl:if test="contains($langs, '|')">
			<xsl:call-template name="targetFiles">
				<xsl:with-param name="langs" select="substring-after($langs, '|')"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template match="/svg | /s:svg">
		<xsl:param name="dataSet"/>
		<xsl:apply-templates select="v:variableSets/v:variableSet/v:variables/v:variable[@trait='textcontent']">
			<xsl:with-param name="dataSet" select="$dataSet"/>
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="v:variable">
		<xsl:param name="dataSet"/>
		<xsl:variable name="varName" select="@varName"/>
		<trans-unit id="{$varName}">
			<source>
				<xsl:apply-templates select="../../v:sampleDataSets/v:sampleDataSet[@dataSetName=$sourceLangDataSet]/c:*[local-name()=$varName]"/>
			</source>
			<xsl:if test="$dataSet">
				<target>
					<xsl:apply-templates select="../../v:sampleDataSets/v:sampleDataSet[@dataSetName=$dataSet]/c:*[local-name()=$varName]"/>
				</target>
			</xsl:if>
		</trans-unit>
	</xsl:template>

	<xsl:template match="c:p">
		<xsl:value-of select="."/>
		<xsl:if test="following-sibling::c:p">
			<x id="x{position()}" ctype="x-html-br" equiv-text=" "/>
		</xsl:if>
	</xsl:template>

	<xsl:template match="text()">
		<xsl:value-of select="normalize-space()"/>
	</xsl:template>
</xsl:stylesheet>